@@ -43,7 +43,7 @@ class BaseSettings(BaseModel):
             if field.alt_alias:
                 env_name = field.alias
             else:
-                env_name = self.config.env_prefix + field.name.upper()
+                env_name = self.__config__.env_prefix + field.name.upper()
             env_var = os.getenv(env_name, None)
             if env_var:
                 if _complex_field(field):
